@@ -51,6 +51,8 @@ def do_front_channel_logout_iframe(cinfo, iss, sid):
     except KeyError:
         flsr = False
 
+    logger.debug(f"frontchannel_logout_uri: {frontchannel_logout_uri}")
+    logger.debug(f"frontchannel_logout_session_required: {flsr}")
     if flsr:
         _query = {"iss": iss, "sid": sid}
         if "?" in frontchannel_logout_uri:
@@ -61,6 +63,7 @@ def do_front_channel_logout_iframe(cinfo, iss, sid):
             _np = p._replace(query="")
             frontchannel_logout_uri = _np.geturl()
 
+        logger.debug(f"IFrame query: {_query}")
         _iframe = '<iframe src="{}?{}">'.format(
             frontchannel_logout_uri, urlencode(_query, doseq=True)
         )
@@ -123,9 +126,9 @@ class Session(Endpoint):
         # always include sub and sid so I don't check for
         # backchannel_logout_session_required
 
-        enc_msg = self._encrypt_sid(sid)
+        # enc_msg = self._encrypt_sid(sid)
 
-        payload = {"sid": enc_msg, "events": {BACK_CHANNEL_LOGOUT_EVENT: {}}}
+        payload = {"sid": sid, "events": {BACK_CHANNEL_LOGOUT_EVENT: {}}}
 
         try:
             alg = cinfo["id_token_signed_response_alg"]
@@ -148,30 +151,54 @@ class Session(Endpoint):
         _context = self.server_get("endpoint_context")
         _mngr = _context.session_manager
         _session_info = _mngr.get_session_info(
-            sid, user_session_info=True, client_session_info=True
+            sid, user_session_info=True, client_session_info=True, grant=True
         )
 
         # Front-/Backchannel logout ?
         _cdb = _context.cdb
         _iss = _context.issuer
         _user_id = _session_info["user_id"]
+        logger.debug(
+            f"(logout_all_clients) user_id={_user_id},  client_id={_session_info['client_id']}, "
+            f"grant_id={_session_info['grant_id']}"
+        )
+
         bc_logouts = {}
         fc_iframes = {}
         _rel_sid = []
         for _client_id in _session_info["user_session_info"].subordinate:
+            # I prefer back-channel. Should it be configurable ?
             if "backchannel_logout_uri" in _cdb[_client_id]:
-                _sid = _mngr.encrypted_session_id(_user_id, _client_id)
-                _rel_sid.append(_sid)
-                _spec = self.do_back_channel_logout(_cdb[_client_id], _sid)
-                if _spec:
-                    bc_logouts[_client_id] = _spec
+                _cli = _mngr.get([_user_id, _client_id])
+                for gid in _cli.subordinate:
+                    grant = _mngr.get([_user_id, _client_id, gid])
+                    # Has to be connected to an authentication event
+                    if not grant.authentication_event:
+                        continue
+                    idt = grant.last_issued_token_of_type("id_token")
+                    if idt:
+                        _rel_sid.append(idt.session_id)
+                        _spec = self.do_back_channel_logout(_cdb[_client_id], idt.session_id)
+                        if _spec:
+                            bc_logouts[_client_id] = _spec
+                        break
             elif "frontchannel_logout_uri" in _cdb[_client_id]:
-                # Construct an IFrame
-                _sid = _mngr.encrypted_session_id(_user_id, _client_id)
-                _rel_sid.append(_sid)
-                _spec = do_front_channel_logout_iframe(_cdb[_client_id], _iss, _sid)
-                if _spec:
-                    fc_iframes[_client_id] = _spec
+                _cli = _mngr.get([_user_id, _client_id])
+                for gid in _cli.subordinate:
+                    grant = _mngr.get([_user_id, _client_id, gid])
+                    # Has to be connected to an authentication event
+                    if not grant.authentication_event:
+                        continue
+                    idt = grant.last_issued_token_of_type("id_token")
+                    if idt:
+                        _rel_sid.append(idt.session_id)
+                        # Construct an IFrame
+                        _spec = do_front_channel_logout_iframe(
+                            _cdb[_client_id], _iss, idt.session_id
+                        )
+                        if _spec:
+                            fc_iframes[_client_id] = _spec
+                        break
 
         self.clean_sessions(_rel_sid)
 
@@ -220,7 +247,7 @@ class Session(Endpoint):
         self,
         request: Optional[Union[Message, dict]] = None,
         http_info: Optional[dict] = None,
-        **kwargs
+        **kwargs,
     ):
         """
         Perform user logout
@@ -252,7 +279,7 @@ class Session(Endpoint):
             if _cookie_infos:
                 # value is a JSON document
                 _cookie_info = json.loads(_cookie_infos[0]["value"])
-                logger.debug("Cookie info: {}".format(_cookie_info))
+                logger.debug("process_request: cookie_info={}".format(_cookie_info))
                 try:
                     _session_info = _mngr.get_session_info(_cookie_info["sid"], grant=True)
                 except KeyError:
@@ -291,7 +318,10 @@ class Session(Endpoint):
         else:
             plur = True
             verify_uri(
-                _context, request, "post_logout_redirect_uri", client_id=_session_info["client_id"],
+                _context,
+                request,
+                "post_logout_redirect_uri",
+                client_id=_session_info["client_id"],
             )
 
         payload = {
@@ -364,6 +394,7 @@ class Session(Endpoint):
         return request
 
     def do_verified_logout(self, sid, alla=False, **kwargs):
+        logger.debug(f"(do_verified_logout): sid={sid}")
         if alla:
             _res = self.logout_all_clients(sid=sid)
         else:
@@ -378,7 +409,10 @@ class Session(Endpoint):
                 logger.info("logging out from {} at {}".format(_cid, _url))
 
                 res = _context.httpc.post(
-                    _url, data="logout_token={}".format(sjwt), **_context.httpc_params
+                    _url,
+                    data="logout_token={}".format(sjwt),
+                    headers={"Content-Type": "application/x-www-form-urlencoded"},
+                    **_context.httpc_params,
                 )
 
                 if res.status_code < 300:
