@@ -25,6 +25,14 @@ from ..token.handler import TokenHandler
 logger = logging.getLogger(__name__)
 
 
+class RawID(object):
+    def __init__(self, *args, **kwargs):
+        pass
+
+    def __call__(self, uid, *args, **kwargs):
+        return uid
+
+
 def pairwise_id(uid, sector_identifier, salt="", **kwargs):
     return hashlib.sha256(
         ("{}{}{}".format(uid, sector_identifier, salt)).encode("utf-8")
@@ -39,7 +47,7 @@ class PairWiseID(object):
             if os.path.isfile(filename):
                 self.salt = open(filename).read()
             elif not os.path.isfile(filename) and os.path.exists(
-                    filename
+                filename
             ):  # Not a file, Something else
                 raise ConfigurationError("Salt filename points to something that is not a file")
             else:
@@ -74,8 +82,10 @@ class SessionManager(Database):
     init_args = ["handler"]
 
     def __init__(
-            self, handler: TokenHandler, conf: Optional[dict] = None,
-            sub_func: Optional[dict] = None,
+        self,
+        handler: TokenHandler,
+        conf: Optional[dict] = None,
+        sub_func: Optional[dict] = None,
     ):
         super(SessionManager, self).__init__()
         self.conf = conf or {}
@@ -117,21 +127,14 @@ class SessionManager(Database):
         return self._salt
 
     def __setattr__(self, key, value):
-        if key in ('_key', '_salt'):
+        if key in ("_key", "_salt"):
             if hasattr(self, key):
                 # not first time we configure it!
-                raise AttributeError(
-                    f"{key} is a ReadOnly attribute "
-                    "that can't be overwritten!"
-                )
+                raise AttributeError(f"{key} is a ReadOnly attribute " "that can't be overwritten!")
         super().__setattr__(key, value)
 
     def _init_db(self):
-        Database.__init__(
-            self,
-            key=self.load_key(),
-            salt=self.load_salt()
-        )
+        Database.__init__(self, key=self.load_key(), salt=self.load_salt())
 
     def get_user_info(self, uid: str) -> UserSessionInfo:
         usi = self.get([uid])
@@ -156,14 +159,14 @@ class SessionManager(Database):
         return None  # pragma: no cover
 
     def create_grant(
-            self,
-            authn_event: AuthnEvent,
-            auth_req: AuthorizationRequest,
-            user_id: str,
-            client_id: Optional[str] = "",
-            sub_type: Optional[str] = "public",
-            token_usage_rules: Optional[dict] = None,
-            scopes: Optional[list] = None,
+        self,
+        authn_event: AuthnEvent,
+        auth_req: AuthorizationRequest,
+        user_id: str,
+        client_id: Optional[str] = "",
+        sub_type: Optional[str] = "public",
+        token_usage_rules: Optional[dict] = None,
+        scopes: Optional[list] = None,
     ) -> str:
         """
 
@@ -183,11 +186,12 @@ class SessionManager(Database):
         grant = Grant(
             authorization_request=auth_req,
             authentication_event=authn_event,
-            sub=self.sub_func[sub_type](user_id, salt=self.salt,
-                                        sector_identifier=sector_identifier),
+            sub=self.sub_func[sub_type](
+                user_id, salt=self.salt, sector_identifier=sector_identifier
+            ),
             usage_rules=token_usage_rules,
             scope=scopes,
-            claims=_claims
+            claims=_claims,
         )
 
         self.set([user_id, client_id, grant.id], grant)
@@ -195,14 +199,14 @@ class SessionManager(Database):
         return self.encrypted_session_id(user_id, client_id, grant.id)
 
     def create_session(
-            self,
-            authn_event: AuthnEvent,
-            auth_req: AuthorizationRequest,
-            user_id: str,
-            client_id: Optional[str] = "",
-            sub_type: Optional[str] = "public",
-            token_usage_rules: Optional[dict] = None,
-            scopes: Optional[list] = None,
+        self,
+        authn_event: AuthnEvent,
+        auth_req: AuthorizationRequest,
+        user_id: str,
+        client_id: Optional[str] = "",
+        sub_type: Optional[str] = "public",
+        token_usage_rules: Optional[dict] = None,
+        scopes: Optional[list] = None,
     ) -> str:
         """
         Create part of a user session. The parts added are user- and client
@@ -316,10 +320,10 @@ class SessionManager(Database):
             self._revoke_dependent(grant, token)
 
     def get_authentication_events(
-            self,
-            session_id: Optional[str] = "",
-            user_id: Optional[str] = "",
-            client_id: Optional[str] = "",
+        self,
+        session_id: Optional[str] = "",
+        user_id: Optional[str] = "",
+        client_id: Optional[str] = "",
     ) -> List[AuthnEvent]:
         """
         Return the authentication events that exists for a user/client combination.
@@ -364,8 +368,19 @@ class SessionManager(Database):
             raise ValueError("Invalid session ID")
 
         _info = self.get([_user_id, _client_id])
+        logger.debug(f"revoke_client_session: {_user_id}:{_client_id}")
         self.set([_user_id, _client_id], _info.revoke())
 
+        # revoked all grants
+        for gid in _info.subordinate:
+            _grant = self.get([_user_id, _client_id, gid])
+            _grant.revoke()
+
+    def client_session_is_revoked(self, session_id: str):
+        _user_id, _client_id, _ = self.decrypt_session_id(session_id)
+        _client_inst = self.get([_user_id, _client_id])
+        return _client_inst.revoked
+
     def revoke_grant(self, session_id: str):
         """
         Revokes the grant pointed to by a session identifier.
@@ -378,10 +393,10 @@ class SessionManager(Database):
         self.set(_path, _info)
 
     def grants(
-            self,
-            session_id: Optional[str] = "",
-            user_id: Optional[str] = "",
-            client_id: Optional[str] = "",
+        self,
+        session_id: Optional[str] = "",
+        user_id: Optional[str] = "",
+        client_id: Optional[str] = "",
     ) -> List[Grant]:
         """
         Find all grant connected to a user session
@@ -402,13 +417,13 @@ class SessionManager(Database):
         return [self.get([user_id, client_id, gid]) for gid in _csi.subordinate]
 
     def get_session_info(
-            self,
-            session_id: str,
-            user_session_info: bool = False,
-            client_session_info: bool = False,
-            grant: bool = False,
-            authentication_event: bool = False,
-            authorization_request: bool = False,
+        self,
+        session_id: str,
+        user_session_info: bool = False,
+        client_session_info: bool = False,
+        grant: bool = False,
+        authentication_event: bool = False,
+        authorization_request: bool = False,
     ) -> dict:
         """
         Returns information connected to a session.
@@ -463,13 +478,13 @@ class SessionManager(Database):
         return sid
 
     def get_session_info_by_token(
-            self,
-            token_value: str,
-            user_session_info: bool = False,
-            client_session_info: bool = False,
-            grant: bool = False,
-            authentication_event: bool = False,
-            authorization_request: bool = False,
+        self,
+        token_value: str,
+        user_session_info: bool = False,
+        client_session_info: bool = False,
+        grant: bool = False,
+        authentication_event: bool = False,
+        authorization_request: bool = False,
     ) -> dict:
         _token_info = self.token_handler.info(token_value)
         sid = _token_info.get("sid")
